@@ -19,21 +19,21 @@ from .exceptions import (CoprException,
 
 
 __all__ = [
-    config_from_file,
-    Client,
+    "config_from_file",
+    "Client",
 
-    BaseProxy,
-    BuildProxy,
-    PackageProxy,
-    MockChrootProxy,
-    ProjectChrootProxy,
-    BuildChrootProxy,
-    ModuleProxy,
+    "BaseProxy",
+    "BuildProxy",
+    "PackageProxy",
+    "MockChrootProxy",
+    "ProjectChrootProxy",
+    "BuildChrootProxy",
+    "ModuleProxy",
 
-    CoprException,
-    CoprRequestException,
-    CoprNoResultException,
-    CoprValidationException,
-    CoprNoConfigException,
-    CoprConfigException,
+    "CoprException",
+    "CoprRequestException",
+    "CoprNoResultException",
+    "CoprValidationException",
+    "CoprNoConfigException",
+    "CoprConfigException",
 ]
