@@ -119,9 +119,9 @@ class PackageProxy(BaseProxy):
 
     def reset(self, ownername, projectname, packagename):
         """
-        Reset a package configuration, meaning that previously selected `source_type`
-        for the package and also all the source configuration previously defined by
-        `source_dict` will be nulled.
+        Reset a package configuration, meaning that previously selected
+        ``source_type`` for the package and also all the source configuration
+        previously defined by ``source_dict`` will be nulled.
 
         :param str ownername:
         :param str projectname:
